@@ -43,16 +43,15 @@ def my_backoff(function):
                 code = e.response.status_code
                 return 400 <= code < 500 and code != 429
 
-            elif isinstance(e, requests.exceptions.ConnectionError):
-                # the event of a network problem (e.g. DNS failure, refused connection, etc)
-                return False
-
-            elif isinstance(e, requests.exceptions.Timeout):
-                # request times out
-                return False
-
-            elif isinstance(e, requests.exceptions.TooManyRedirects):
-                # a request exceeds the configured number of maximum redirections
+            elif isinstance(
+                e,
+                (
+                    requests.exceptions.TooManyRedirects,
+                    requests.exceptions.Timeout,
+                    requests.exceptions.ConnectionError,
+                    ConnectionError,
+                ),
+            ):
                 return False
 
             else:
@@ -78,6 +77,10 @@ class AnnofabApi(AbstractAnnofabApi):
         login_user_id: AnnoFabにログインするときのユーザID
         login_password: AnnoFabにログインするときのパスワード
         endpoint_url: AnnoFab APIのエンドポイント。
+
+    Attributes:
+        token_dict: login, refresh_tokenで取得したtoken情報
+        cookies: Signed Cookie情報
     """
 
     def __init__(self, login_user_id: str, login_password: str, endpoint_url: str = DEFAULT_ENDPOINT_URL):
@@ -91,13 +94,13 @@ class AnnofabApi(AbstractAnnofabApi):
         self.url_prefix = f"{endpoint_url}/api/v1"
         self.session = requests.Session()
 
-    #: login, refresh_tokenで取得したtoken情報
-    token_dict: Optional[Dict[str, Any]] = None
+        #: login, refresh_tokenで取得したtoken情報
+        self.token_dict: Optional[Dict[str, Any]] = None
 
-    #: Signed Cookie情報
-    cookies: Optional[RequestsCookieJar] = None
+        #: Signed Cookie情報
+        self.cookies: Optional[RequestsCookieJar] = None
 
-    __account_id: Optional[str] = None
+        self.__account_id: Optional[str] = None
 
     class __MyToken(AuthBase):
         """
@@ -200,7 +203,7 @@ class AnnofabApi(AbstractAnnofabApi):
         request_body: Optional[Any] = None,
     ) -> Tuple[Any, requests.Response]:
         """
-        HTTP　Requestを投げて、Responseを返す。
+        HTTP Requestを投げて、Responseを返す。
 
         Args:
             http_method:
@@ -237,7 +240,9 @@ class AnnofabApi(AbstractAnnofabApi):
         content = self._response_to_content(response)
         return content, response
 
-    def _get_signed_cookie(self, project_id) -> Tuple[Dict[str, Any], requests.Response]:
+    def _get_signed_cookie(
+        self, project_id, query_params: Optional[Dict[str, Any]] = None
+    ) -> Tuple[Dict[str, Any], requests.Response]:
         """
         アノテーション仕様の履歴情報を取得するために、非公開APIにアクセスする。
         変更される可能性あり.
@@ -251,7 +256,7 @@ class AnnofabApi(AbstractAnnofabApi):
         """
         url_path = f"/internal/projects/{project_id}/sign-headers"
         http_method = "GET"
-        keyword_params: Dict[str, Any] = {}
+        keyword_params: Dict[str, Any] = {"query_params": query_params}
         return self._request_wrapper(http_method, url_path, **keyword_params)
 
     def _request_get_with_cookie(self, project_id: str, url: str) -> requests.Response:
@@ -266,23 +271,22 @@ class AnnofabApi(AbstractAnnofabApi):
             Response
 
         """
-
-        def request(cookies):
-            kwargs = {"cookies": cookies}
-            return self.session.get(url, **kwargs)
-
-        if self.cookies is None:
-            _, r = self._get_signed_cookie(project_id)
-            self.cookies = r.cookies
-
-        response = request(self.cookies)
+        # Sessionオブジェクトに保存されているCookieを利用して、URLにアクセスする
+        response = self.session.get(url)
 
         # CloudFrontから403 Errorが発生したときは、別プロジェクトのcookieを渡している可能性があるので、
         # Signed Cookieを発行して、再度リクエストを投げる
         if response.status_code == requests.codes.forbidden and response.headers.get("server") == "CloudFront":
-            _, r = self._get_signed_cookie(project_id)
-            self.cookies = r.cookies
-            response = request(self.cookies)
+            query_params = {}
+            if "/input_data_set/" in url:
+                query_params.update({"resource": "input_data_set"})
+            else:
+                query_params.update({"resource": "project"})
+
+            _, r = self._get_signed_cookie(project_id, query_params=query_params)
+            for cookie in r.cookies:
+                self.session.cookies.set_cookie(cookie)
+            response = self.session.get(url)
 
         _log_error_response(logger, response)
         _raise_for_status(response)
